==> TerraVide-0.1.5.tar.gz: TerraVide-0.1.5/setup.py <==
#------------------------------------------------------------------------------------------------------------------------------
#
# Created on Thu Apr 13 2023
#
# Author :  Sarang Pramode
#
# The MIT License (MIT)
# Copyright (c) 2023 Sarang Pramode
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software
# and associated documentation files (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial
# portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
#
#------------------------------------------------------------------------------------------------------------------------------

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

print(setuptools.find_packages())

setuptools.setup(
    name="TerraVide",                     # This is the name of the package
    version="0.1.5",                        #release version
    author="Sarang Pramode",                     # Full name of the author
    description="An open source python package to process and simulate large urban environments mapped with LiDAR data",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    license='MIT',
    packages=setuptools.find_packages(),    # List of all python modules to be installed
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],                                      # Information to filter the project on PyPi website
    python_requires='>=3.6',                # Minimum version requirement of the package
    py_modules=["info","dataset"],             # Name of the python package
    install_requires=[              # Install other dependencies if any
        "numpy",
        "pandas",
        "os",
        "ftplib",
    ]                     
)

==> TerraVide-0.1.6.tar.gz: TerraVide-0.1.6/setup.py <==
#------------------------------------------------------------------------------------------------------------------------------
#
# Created on Thu Apr 13 2023
#
# Author :  Sarang Pramode
#
# The MIT License (MIT)
# Copyright (c) 2023 Sarang Pramode
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software
# and associated documentation files (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial
# portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
#
#------------------------------------------------------------------------------------------------------------------------------

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

print(setuptools.find_packages())

setuptools.setup(
    name="TerraVide",                     # This is the name of the package
    version="0.1.6",                        #release version
    author="Sarang Pramode",                     # Full name of the author
    description="An open source python package to process and simulate large urban environments mapped with LiDAR data",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    license='MIT',
    packages=setuptools.find_packages(),    # List of all python modules to be installed
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],                                      # Information to filter the project on PyPi website
    python_requires='>=3.6',                # Minimum version requirement of the package
    #py_modules=["info","dataset"],             # Name of the python package
    install_requires=[              # Install other dependencies if any
        "numpy",
        "pandas",
        "laspy",
    ]                     
)
